import { request } from 'umi';
import { getDataBaseUrl } from '@/global_data';
/** 获取列表  */
export async function GetWarehousetemplatePage(data) {
  return request(getDataBaseUrl()+`/api/warehousetemplate/page`, {
    method: 'POST',
    data: data,
  });
}
export async function WarehousetemplateAdd(data) {
    return request(getDataBaseUrl()+`/api/warehousetemplate/add`, {
      method: 'POST',
      data: data,
    });
  }
export async function WarehousetemplateUpdate(data) {
    return request(getDataBaseUrl()+`/api/warehousetemplate/update`, {
      method: 'POST',
      data: data,
    });
  }
  export async function WarehousetemplateDel(data) {
    return request(getDataBaseUrl()+`/api/warehousetemplate/del`, {
      method: 'POST',
      data: data,
    });
  }
  export async function Getdevice() {
    return request(getDataBaseUrl()+`/api/device/list`, {
      method: 'Get'
    });
  }
  export async function GetBatching() {
    return request(getDataBaseUrl()+'/api/batching/getbatchingselectlist', {
      method: 'Get',
    });
  }